@@ -6,7 +6,7 @@ import yaml
 from ruamel.yaml import YAML
 from pathlib import Path
 import re
-
+import torch
 
 def to_yolo(pxl_annotations_dict=None,labelmap=None, base_imgdir=None, targetdir=None, prop=0.7, copy_image=True):
     """
@@ -109,8 +109,8 @@ def generate_yaml(yamlname, targetdir, labelmap):
         os.mkdir(os.path.join(targetdir, "data"))
 
     dict_file = {   
-                    'train' : '../{}/{}/train'.format(targetdir, "images"),
-                    'val' : '../{}/{}/val'.format(targetdir, "images"),
+                    'train' : '{}/{}/train'.format(targetdir, "images"),
+                    'val' : '{}/{}/val'.format(targetdir, "images"),
                     'nc': len(labelmap),
                     'names': list(labelmap.values())
                     }
@@ -151,7 +151,7 @@ def edit_model_yaml(label_map, experiment_name, config_path=None):
         tmp = opath.replace('./yolov5','.')
     
     else:
-        tmp = '../'+ymlpath.split('.')[0]+experiment_name+'.'+ymlpath.split('.')[1]
+        tmp = ymlpath.split('.')[0]+experiment_name+'.'+ymlpath.split('.')[1]
 
     return tmp
 
@@ -198,7 +198,57 @@ def tf_events_to_dict(path, type=''):
     return log_dict
 
 
+def setup_hyp(exp_name, cfg, checkpoint_dir, params={}, label_map=[]):
+    YOLOSIZE = cfg.split('/')[2][6]
+    YOLODIR = 'YOLO-{}'.format(exp_name)
 
+    model_exp_name = "yolov5{}_{}".format(YOLOSIZE, exp_name)
+    data_yaml = '{}/data/{}.yaml'.format(YOLODIR, exp_name)
+
+    tmp = os.listdir(checkpoint_dir)
+    for f in tmp:
+        if f.endswith('.pt'):
+            weight_path = os.path.join(checkpoint_dir, f)
+        if f.endswith('.yaml'):
+            hyp_path = os.path.join(checkpoint_dir, f)
+
+    opt = Opt()
+    opt.batch_size = 4 if not 'batch_size' in params.keys() else params["batch_size"]
+    opt.epochs = 100 if not 'steps' in params.keys() else params["steps"] 
+    opt.data = data_yaml
+    opt.cfg = cfg 
+    opt.weights = weight_path 
+    opt.name = model_exp_name
+    opt.img_size =  [640, 640] if not 'input_shape' in params.keys() else params["input_shape"]
+    opt.hyp = hyp_path if not 'hyperparams' in params.keys() else params["hyperparams"]
+
+    opt.resume = False
+    opt.bucket = ''
+    opt.device = 'cuda:0' if torch.cuda.is_available() else 'cpu'
+    opt.local_rank = -1 
+    opt.log_imgs = 4
+    opt.workers = 4
+    opt.project = '{}/runs/train'.format(YOLODIR)
+    opt.entity = None 
+    opt.evolve = False
+    opt.exist_ok = True
+    opt.single_cls = (len(label_map) == 1)
+    opt.adam = True
+    opt.linear_lr = True
+    opt.sync_bn = False
+    opt.cache_images = False 
+    opt.multi_scale = True
+    opt.rect = True
+    opt.image_weights = False
+    opt.quad = False
+    opt.noautoanchor = False
+    opt.notest = False
+    opt.nosave = False
+    with open(opt.hyp) as f:
+        hyp = yaml.load(f, Loader=yaml.SafeLoader)  # load hyps
+
+    device = 'cuda:0' if torch.cuda.is_available() else 'cpu'
+    return hyp, opt, device
 
 class Opt():
     pass
\ No newline at end of file
